summaryrefslogtreecommitdiff
path: root/qutebrowser/mainwindow/tabbedbrowser.py
diff options
context:
space:
mode:
authorJimmy <jimmy@spalge.com>2019-05-25 19:37:51 +1200
committerJimmy <jimmy@spalge.com>2020-07-13 12:41:45 +1200
commit19ccaba0b96f0a9702a80b1728dedb2ea08a7535 (patch)
tree86b93b1dc1146e2eafde252bc8068ba65b826b75 /qutebrowser/mainwindow/tabbedbrowser.py
parentdf9e20fea4bafe7aadb3c7c42e5f2d03b3fe38c4 (diff)
downloadqutebrowser-19ccaba0b96f0a9702a80b1728dedb2ea08a7535.tar.gz
qutebrowser-19ccaba0b96f0a9702a80b1728dedb2ea08a7535.zip
Rename TabbedBrowser.shutting_down
It was made public in 1c10a1aecfd50 and the method that used it externally was removed in 08bb3f4f19b51. I renamed it to be the same as in the views and so I can add a shutting_down signal. As an aside the `Application.new_window` signal that was also added for 1c10a1aecfd50 also had its sole consumer removed in that refactoring. I can see more future use of it though.
Diffstat (limited to 'qutebrowser/mainwindow/tabbedbrowser.py')
-rw-r--r--qutebrowser/mainwindow/tabbedbrowser.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/qutebrowser/mainwindow/tabbedbrowser.py b/qutebrowser/mainwindow/tabbedbrowser.py
index 987fad3ac..7387fcecc 100644
--- a/qutebrowser/mainwindow/tabbedbrowser.py
+++ b/qutebrowser/mainwindow/tabbedbrowser.py
@@ -160,7 +160,7 @@ class TabbedBrowser(QWidget):
tabs.new_tab_position set to 'prev'.
_tab_insert_idx_right: Same as above, for 'next'.
_undo_stack: List of lists of UndoEntry objects of closed tabs.
shutting_down: Whether we're currently shutting down.
_local_marks: Jump markers local to each page
_global_marks: Jump markers used across all pages
default_window_icon: The qutebrowser window icon
@@ -206,7 +206,7 @@ class TabbedBrowser(QWidget):
self._win_id = win_id
self._tab_insert_idx_left = 0
self._tab_insert_idx_right = -1
- self.shutting_down = False
+ self.is_shutting_down = False
self.widget.tabCloseRequested.connect(self.on_tab_close_requested)
self.widget.new_tab_requested.connect(
self.tabopen) # type: ignore[arg-type]
@@ -381,7 +381,7 @@ class TabbedBrowser(QWidget):
def shutdown(self):
"""Try to shut down all tabs cleanly."""
- self.shutting_down = True
+ self.is_shutting_down = True
# Reverse tabs so we don't have to recalculate tab titles over and over
# Removing first causes [2..-1] to be recomputed
# Removing the last causes nothing to be recomputed
@@ -822,7 +822,7 @@ class TabbedBrowser(QWidget):
def _on_current_changed(self, idx):
"""Add prev tab to stack and leave hinting mode when focus changed."""
mode_on_change = config.val.tabs.mode_on_change
- if idx == -1 or self.shutting_down:
+ if idx == -1 or self.is_shutting_down:
# closing the last tab (before quitting) or shutting down
return
tab = self.widget.widget(idx)
@@ -160,7 +160,7 @@ class TabbedBrowser(QWidget):
_tab_insert_idx_right: Same as above, for 'next'.
_undo_stack: List of lists of UndoEntry objects of closed tabs.
- shutting_down: Whether we're currently shutting down.
+ is_shutting_down: Whether we're currently shutting down.
_local_marks: Jump markers local to each page
_global_marks: Jump markers used across all pages